@@ -1,14 +1,11 @@
-from __future__ import print_function
-
 import argparse
-import sys
 from typing import Optional
 from typing import Sequence
 
 import toml
 
 
-def main(argv=None):  # type: (Optional[Sequence[str]]) -> int
+def main(argv: Optional[Sequence[str]] = None) -> int:
     parser = argparse.ArgumentParser()
     parser.add_argument('filenames', nargs='*', help='Filenames to check.')
     args = parser.parse_args(argv)
@@ -16,13 +13,12 @@ def main(argv=None):  # type: (Optional[Sequence[str]]) -> int
     retval = 0
     for filename in args.filenames:
         try:
-            with open(filename) as f:
-                toml.load(f)
+            toml.load(filename)
         except toml.TomlDecodeError as exc:
-            print('{}: {}'.format(filename, exc))
+            print(f'{filename}: {exc}')
             retval = 1
     return retval
 
 
 if __name__ == '__main__':
-    sys.exit(main())
+    exit(main())
