@@ -36,7 +36,7 @@ class Requirement:
 
         return name[:m.start()]
 
-    def __lt__(self, requirement: 'Requirement') -> int:
+    def __lt__(self, requirement: 'Requirement') -> bool:
         # \n means top of file comment, so always return True,
         # otherwise just do a string comparison with value.
         assert self.value is not None, self.value
@@ -95,7 +95,7 @@ def fix_requirements(f: IO[bytes]) -> int:
                 requirement.value = b'\n'
             else:
                 requirement.comments.append(line)
-        elif line.startswith(b'#') or line.strip() == b'':
+        elif line.lstrip().startswith(b'#') or line.strip() == b'':
             requirement.comments.append(line)
         else:
             requirement.append_value(line)
